| ALLOWED_OPERATORS | R Documentation |
Provides secure parsing, syntax tree validation, and vectorized evaluation of mathematical expressions on multispectral raster layers and numeric values.
ALLOWED_OPERATORS
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.