| safe_divide | R Documentation |
Performs division with protection against division by zero, near-zero denominator
singularities ($|den| < tol$), and non-finite values (Inf, -Inf, NaN),
replacing invalid results with NA.
safe_divide(num, den, tol = 1e-06)
num |
Numerator ( |
den |
Denominator ( |
tol |
Singularity tolerance threshold. Values with $|den| < tol$ are safely
converted to |
An object of the same class as inputs with values safely bounded and
non-finite values replaced by NA.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.