| band_mapping | R Documentation |
Provides standard band name mappings for commonly used multispectral sensors and generic naming conventions.
band_mapping(
sensor = c("generic", "sentinel2", "s2", "landsat8", "landsat9", "l8", "l9",
"landsat7", "landsat5", "tm", "etm")
)
sensor |
Character string specifying the sensor preset. Supported options:
Defaults to |
A named character vector where names represent standardized spectral
band roles (e.g., "nir", "red") and values represent corresponding
band or layer names for the selected sensor.
# Generic mapping
band_mapping("generic")
# Sentinel-2 band mapping
band_mapping("sentinel2")
# Landsat 8/9 band mapping
band_mapping("landsat8")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.