| calc_arvi | R Documentation |
Computes the Atmospherically Resistant Vegetation Index (ARVI), which uses the difference between blue and red bands to reduce atmospheric aerosol effects on red reflectance.
calc_arvi(nir, red, blue, gamma = 1)
nir |
Near-infrared band ( |
red |
Red band ( |
blue |
Blue band ( |
gamma |
Aerosol resistance coefficient. Defaults to |
ARVI = \frac{NIR - RB}{NIR + RB}
where RB = RED - \gamma \times (BLUE - RED).
A terra::SpatRaster (named "ARVI") or numeric vector with index values.
Kaufman, Y. J., & Tanre, D. (1992). Atmospherically resistant vegetation index (ARVI) for EOS-MODIS. IEEE TGRS, 30(2), 261-270.
calc_ndvi, calc_evi, geo_index
calc_arvi(nir = 0.7, red = 0.2, blue = 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.