| calc_msavi | R Documentation |
Computes the Modified Soil Adjusted Vegetation Index 2 (MSAVI2), which eliminates the need
for manually finding or specifying a soil adjustment factor L.
calc_msavi(nir, red)
nir |
Near-infrared band ( |
red |
Red band ( |
MSAVI = \frac{2 \times NIR + 1 - \sqrt{(2 \times NIR + 1)^2 - 8 \times (NIR - RED)}}{2}
Description & Purpose: MSAVI simplifies SAVI by calculating an inductive soil adjustment factor mathematically, providing high sensitivity in sparse vegetation without requiring empirical soil line parameters.
A terra::SpatRaster (named "MSAVI") or numeric vector with index values.
Qi, J., Chehbouni, A., Huete, A. R., Kerr, Y. H., & Sorooshian, S. (1994). A modified soil adjusted vegetation index. Remote Sensing of Environment, 48(2), 119-126.
calc_savi, calc_osavi, geo_index
# Numeric scalar calculation
calc_msavi(nir = 0.7, red = 0.2)
# Raster layer calculation
img <- get_example_data()
msavi_rast <- calc_msavi(nir = img[["nir"]], red = img[["red"]])
print(msavi_rast)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.