| plot_index | R Documentation |
Plots a single-layer or selected layer from a terra::SpatRaster index object
using tailored color palettes designed for vegetation, water, soil, urban, and custom analysis.
plot_index(x, index = NULL, main = NULL, col = NULL, ...)
x |
A |
index |
Optional character string specifying which layer to plot if |
main |
Optional plot title. Defaults to the layer name. |
col |
Optional color palette. If |
... |
Additional graphical arguments passed to |
Invisible terra::SpatRaster object that was plotted.
img <- get_example_data()
ndvi <- geo_index(img, "NDVI")
plot_index(ndvi)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.