| validate_raster_input | R Documentation |
Verifies that the provided input is either a valid terra::SpatRaster
object or a valid file path pointing to an existing raster file on disk.
If a file path is provided, it is automatically loaded as a SpatRaster.
validate_raster_input(x, arg_name = "image")
x |
An object or file path to check. |
arg_name |
Character string specifying the argument name for error messages. |
A terra::SpatRaster object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.